@@ -1,9 +1,11 @@
 skip_conditionally()
 
 # Logging
+stopJulia()
 system2("julia", '-e "using InteractiveUtils; println(versioninfo());"')
-start_with_threads(verbose = TRUE)
+start_with_threads(max_threads = 2, verbose = TRUE)
 set_projenv(verbose = TRUE)
+cat(JuliaConnectoR::juliaCall("Pkg.status"))
 cat(readLines(file.path(jlmerclusterperm:::.jlmerclusterperm$opts$projdir, "Manifest.toml")), sep = "\n")
 stopJulia()
 
